AC_DEFUN([TH_CHECK_CURSES],
  [
   th_save_LIBS="$LIBS"
   CURSES_LIB=""
   AC_CACHE_CHECK([for working ncurses], th_cv_ncurses,
     [LIBS="$th_save_LIBS -lncurses"
      AC_TRY_LINK(
	[#include <ncurses.h>],
	[chtype a; int b=A_STANDOUT, c=KEY_LEFT; initscr(); ],
	th_cv_ncurses=yes, th_cv_ncurses=no)])
   if test "$th_cv_ncurses" = yes
   then
     AC_DEFINE(HAVE_CURSES_H, 1, [Whether we have a curses library])
     AC_DEFINE(HAVE_NCURSES_H, 1, [Whether our curses library is ncurses])
     CURSES_LIB="-lncurses"
   fi
   if test x"$CURSES_LIB" = x
   then
     AC_CACHE_CHECK([for working curses], th_cv_curses,
       [LIBS="$th_save_LIBS -lcurses"
        AC_TRY_LINK(
          [#include <curses.h>],
          [chtype a; int b=A_STANDOUT, c=KEY_LEFT; initscr(); ],
          th_cv_curses=yes, th_cv_curses=no)])
     if test "$th_cv_curses" = yes
     then
       AC_DEFINE(HAVE_CURSES_H, 1, [Whether we have a curses library])
       CURSES_LIB="-lcurses"
     fi
   fi
   if test x"$CURSES_LIB" != x
   then
     AC_CACHE_CHECK([whether curses supports color], th_cv_curses_color,
       [LIBS="$th_save_LIBS $CURSES_LIB"
        AC_TRY_LINK(
          [#include <curses.h>],
          [initscr(); has_colors();],
          th_cv_curses_color=yes, th_cv_curses_color=no)])
     if test "$th_cv_curses_color" = yes
     then
       AC_DEFINE(HAVE_CURSES_COLOR, 1,
	   [Whether our curses library supports colour])
     fi
   fi
   if test x"$CURSES_LIB" != x
   then
     AC_CACHE_CHECK([whether curses supports terminal resizing], th_cv_curses_resize,
       [LIBS="$th_save_LIBS $CURSES_LIB"
        AC_TRY_LINK(
          [#include <curses.h>],
          [initscr(); resizeterm(LINES, COLS); wresize(stdscr, LINES, COLS);],
          th_cv_curses_resize=yes, th_cv_curses_resize=no)])
     if test "$th_cv_curses_resize" = yes
     then
       AC_DEFINE(HAVE_CURSES_RESIZE, 1,
	   [Whether our curses library supports terminal resize])
     fi
   fi
   LIBS="$th_save_LIBS"
])dnl


dnl Checks we can find inn binaries and uses innconfval to work out 
dnl PATH if so
AC_DEFUN([TH_CHECK_INN],
 [
  TH_SAVE_PATH=$PATH
  PATH=$PATH:/usr/local/news/bin:/usr/lib/news/bin:/var/lib/news/bin
  AC_MSG_CHECKING([for INN PATH])
  NEWS_PATH=
  if innconfval -v > /dev/null 2>/dev/null
  then
      eval `innconfval -s | grep PATHBIN | sed -e 's/PATHBIN/NEWS_PATH/; s/;.*//'`
  fi
  if test x$NEWS_PATH = "x"
  then
      if test -x /usr/lib/news/bin/ctlinnd
      then
	  NEWS_PATH=/usr/lib/news/bin
      elif test -x /usr/local/news/bin/ctlinnd
      then
	  NEWS_PATH=/usr/local/news/bin
      elif test -x /var/lib/news/bin/ctlinnd
      then
	  NEWS_PATH=/var/lib/news/bin
      fi
  fi
  if test x$NEWS_PATH = "x"
  then
      AC_MSG_RESULT([no])
  else
      AC_MSG_RESULT([$NEWS_PATH])
  fi
  PATH=$TH_SAVE_PATH
])dnl

dnl Checks that a directory isn't in /var/spool/sn without being hidden
AC_DEFUN([TH_CHECK_SN_EXPOSED],
 [
  if echo $1 | grep "^/var/spool/sn"
  then
      if echo $1 | grep '^/var/spool/sn/\.'
      then
	  :
      else
	  AC_MSG_WARN([Configuration directories in /var/spool/sn should be hidden])
      fi
  fi
])dnl

dnl Checks that PIPE_BUF is greater than a certain value
AC_DEFUN([TH_CHECK_PIPE_BUF],
[
    AC_MSG_CHECKING([whether PIPE_BUF > $1])
    AC_COMPILE_IFELSE([[
	#include <limits.h>
	#if (PIPE_BUF <= $1)
	#error "PIPE_BUF <= $1\n"
	#endif
    ]],
    AC_MSG_RESULT([yes]),
    [
	AC_MSG_RESULT([no])
	AC_MSG_FAILURE([PIPE_BUF is too small])
    ])
])dnl

dnl Generates AC_ARG_WITH statement setting DEFAULT_$2_DIR to value given
dnl by --with-$1-dir, described in help by $3
AC_DEFUN([TH_DEFAULT_DIR],
[
    AC_ARG_WITH([$1-dir],
	AC_HELP_STRING([--with-$1-dir],
	    [Default path to $3; may be overridden at run-time, or auto-detected if not specified]),
	[ DEFAULT_$2_DIR=$withval ],
	[ DEFAULT_$2_DIR="" ])
    AC_SUBST([DEFAULT_$2_DIR])
])dnl

