#ifndef BACKFILL_H
#define BACKFILL_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Keeps track of articles which are unavailable, in case they become available
 * later */


#ifndef DEFNS_H
#include "defns.h"
#endif

#include "vector.h"

/* A single article */
typedef struct
{
    long int artnum;
    long int day;
    BOOL just_added;		/* Has been added in this session, so no point
				   in asking for it again yet */
    BOOL no_xover;		/* Article is missing from XOVER/XHDR */
} BackFillArticle;

/* All articles in a particular group on a particular server */
typedef struct BackFillGroup
{
    struct BackFillGroup *next;
    long int num_arts;		/* Number of entries contained in list */
    const char *group_name;
    VECTOR_MEMBERS(BackFillArticle);
    size_t current;		/* Used to maintain state when iterating
				   members across function calls */
} BackFillGroup;

/* All groups on a particular server */
typedef struct BackFillServer
{
    const char *server_id;
    BackFillGroup *groups;
} BackFillServer;


/* Loads list (of lists) of all the backfill articles for a given server,
 * pruning those  which have expired (older than expiry days) */
BackFillServer *backfill_load(const char *server_id);

/* Saves above list(s) */
void backfill_save(const BackFillServer *, long int expiry);

/* Returns list of articles for a named group, or NULL if there isn't a list
 * for that group */
BackFillGroup *backfill_get_group(BackFillServer *, const char *group_name);

/* Adds a group to a server: doesn't check for duplicates */
BackFillGroup *backfill_add_group(BackFillServer *, const char *group_name);

/* Adds an article if it isn't already on the list, returning TRUE if it was;
 * new articles are given today's day code. no_xover is whether the gap in
 * article numbering has been found in XOVER or when trying to fetch. */
BOOL backfill_add_unavailable(BackFillGroup *, long int artnum, BOOL no_xover);

/* Removes a previously unavailable article from the list when it has become
 * available */
void backfill_remove_available(BackFillGroup *, long int artnum);

/* Removes all backfill articles lower than a group's lowest article number */
void backfill_remove_old(BackFillGroup *, long int artnum);

#endif /* BACKFILL_H */
