#ifndef CHILD_H
#define CHILD_H

/*
	newsstar - advanced news fetcher
	Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Child's representation of itself */


#ifndef COMMON_H
#include "common.h"
#endif

#ifndef INTERCOM_H 
#include "intercom.h"
#endif

#ifndef PIPELINE_DEPTH
#define PIPELINE_DEPTH 4
#elif (PIPELINE_DEPTH < 1)
#undef PIPELINE_DEPTH
#define PIPELINE_DEPTH 1
#endif

struct ChildData {
	char *server;
	IntercomQ *in_q;	    /* For reading messages to us */
	Intercom *intercom;
	IntercomQ *out_q;	    /* For sending messages to parent */
	rw_buf *sbuf;	    	/* For NNTP socket */
	char *path;

	BOOL path_done, all_requested;
	BOOL pipeline;
	BOOL ignore_436;

	int thread_idx;
	int pipeline_depth;
	long int rq_group_ix;	/* Group to request articles from */

#if ENABLE_ICONV
	const char *to_charset;
	const char *from_charset;
	const char *ole_charset;
	const char *transfer_encoding;
#define ICONV_NULL NULL, NULL, NULL, NULL,
#else
#define ICONV_NULL
#endif

	long int group_ix[PIPELINE_DEPTH];
	long int artnum[PIPELINE_DEPTH];
	BOOL change_group[PIPELINE_DEPTH];
	BOOL backfill[PIPELINE_DEPTH];
	BOOL sent_quit;
	char *path_filter_line;
};

#define CHILD_NULL { \
	NULL, NULL, NULL, NULL, NULL, NULL, \
	FALSE, FALSE, TRUE, FALSE, \
	0, 0, -1, \
	ICONV_NULL \
	{0}, {0}, {0}, {0}, \
	FALSE, \
	NULL \
}

void child_start(int thread_idx, IntercomQ *in_q, IntercomQ *out_q);

/* Declared so rw can send stats */
void child_send_command(ChildData *child_data,
		intercom_Command code, const char *data, ...);

ChildData *child_data_from_index(int thread_idx);

#if USE_PTHREADS
int child_lookup_current_thread_idx(void);
#endif

#endif /* CHILD_H */
