#ifndef GROUP_H
#define GROUP_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Data for newsgroups */


#include <stdio.h>

#include "backfill.h"
#include "groupcount.h"
#include "hashtree.h"

typedef enum {
    group_Virginal,
    group_Allocated,		/* Group has been allocated to a thread, but
				   thread hasn't started yet */
    group_Entering,		/* A thread is now active on this group, but
				   article numbers are not yet valid */
    group_Downloading,
    group_AllDone,
    group_Bogus			/* Group doesn't exist on server */
} group_Status;

typedef enum {
    artnum_Unknown,
    artnum_Unavailable,
    artnum_Available,
    artnum_Duplicate,
    artnum_Killed,
    artnum_Touched
} artnum_Status;

typedef struct {
    artnum_Status status;
    MsgIdNode *msgid;
} group_artnum;
    

struct GroupData {
    char *name;
    long int first_available;
    long int last_available;
    long int last_downloaded;	/* 0 means download all */
    long int last_requested;
    group_Status status;
    group_artnum *artnums;
    int nthreads;
    BackFillGroup *bfgroup;
    ServerData *serv;
    GroupCountData *gc;
};

GroupData *group_new(const char *name, long int last_downloaded,
	ServerData *serv);

void group_delete(GroupData *);

/* Returns whether any articles need to be downloaded; identifier is server id
 * for logging */
BOOL group_got_stats(GroupData *, long int first_available, long int
	last_available, int thread_ix);

/* Indicate that a message is available for download; returns TRUE if it's
 * already in history and definitely shouldn't be downloaded */
BOOL group_add_message_id(GroupData *, long int artnum, const char *msgid);

/* Much as above */
BOOL group_kill_message_id(GroupData *, long int artnum, const char *msgid);

/* Get next article number available for download, 0 for all done, -1 if any
 * still have status artnum_Unknown.
 * If msgid is NULL, don't actually earmark article for download, just return
 * what would be downloaded */
long int group_get_next_article(GroupData *, char const **msgid);

/* Once all articles in a group have been XHDR'd we know that any left marked
 * Unknown are now Unavailable */
void group_prune_unavailable(GroupData *);

/* Update data when a message has been downloaded */
void group_have_downloaded(GroupData *, long int artnum);

/* Writes newsrc data into file when fetch is complete */
void group_write_newsrc(GroupData *, FILE *fp);

/* Gets the group's BackFillGroup; 'create' means create it if it doesn't
 * already exist: use for adding articles to backfill list */
BackFillGroup *group_get_backfill(GroupData *, BOOL create);

/* Add an unavailable article to backfill list */
void group_add_backfill(GroupData *, long int artnum, BOOL no_xover);

#endif /* ! GROUP_H */
