/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"

#include "hashtree.h"
#include "history.h"

static MsgIdNode *msgidnode_new(const char *msgid)
{
    MsgIdNode *node = XMALLOC(sizeof(MsgIdNode));

    node->msgid = XSTRDUP(msgid);
    node->status = msgid_Virginal;
    node->prev = node->next = NULL;
    return node;
}

/* Traverses tree starting at node, to find an existing node, or where to
 * insert a new one.  result parameter is written with result of strcmp(msgid,
 * msgid_of_found_node) */
static MsgIdNode *msgidnode_traverse(MsgIdNode *node, const char *msgid, int
	*result)
{
    MsgIdNode *oldnode = node;
    
    if (result)
	*result = 1;
    while (node)
    {
	int res = strcmp(msgid, node->msgid);

	oldnode = node;
	if (result)
	    *result = res;
	if (!res)
	    return node;
	else if (res < 0)
	    node = node->prev;
	else
	    node = node->next;
    }
    return oldnode;
}

HashTree *hashtree_new(void)
{
    int i;
    HashTree *ht = XMALLOC(sizeof(HashTree));

    for (i = 0; i < 96; ++i)
	ht->hash[i] = NULL;
    return ht;
}

/* Returns either an existing MsgIdNode or, if create is set, creates a new one
 * if it doesn't already exist */
static MsgIdNode *hashtree_traverse(HashTree *ht, const char *msgid, BOOL
	create)
{
    int lures;
    MsgIdNode *node = msgidnode_traverse(ht->hash[msgid[1] - 32], msgid,
		    &lures);

    if (lures && create)
    {
	MsgIdNode *newnode = msgidnode_new(msgid);
	
	if (!node)
	{
	    ht->hash[msgid[1] - 32] = newnode;
	}
	else if (lures < 0)
	{
	    node->prev = newnode;
	}
	else /* if (lures > 0) */
	{
	    node->next = newnode;
	}
	return newnode;
    }
    if (lures /* && !create */)
	return NULL;
    if (node && node->status == msgid_Virginal)
	node->status = msgid_Ready;
    return node;
}

MsgIdNode *hashtree_lookup(HashTree *ht, const char *msgid)
{
    return hashtree_traverse(ht, msgid, FALSE);
}

MsgIdNode *hashtree_add(HashTree *ht, const char *msgid)
{
    return hashtree_traverse(ht, msgid, TRUE);
}

void hashtree_change_status(MsgIdNode *node, msgid_Status status)
{
    node->status = status;
    if (status == msgid_Fetched || status == msgid_Killed)
	history_add(node->msgid);
}

HashTree *the_hashtree = NULL;

