#ifndef HASHTREE_H 
#define HASHTREE_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Message-IDs are stored in a number of binary trees, hashed by their 1st
 * character */


#ifndef DEFNS_H
#include "defns.h"
#endif

/* msgid strings always include <> */

typedef enum {
    msgid_Virginal,	/* Message has just been added for first time */
    msgid_Ready,	/* Message has already been added, whichever server
			   gets to it first will download it */
    msgid_Killed,	/* Killfiled */
    msgid_BeingFetched,	/* Currently being fetched, don't ask for it again */
    msgid_Fetched	/* Has been fetched, or can't be fetched */
} msgid_Status;

typedef struct MsgIdNode MsgIdNode;

struct MsgIdNode {
    MsgIdNode *prev;
    MsgIdNode *next;
    msgid_Status status;
    char *msgid;
};

struct HashTree {
    MsgIdNode *hash[96];
};

HashTree *hashtree_new(void);

/* These structures are never deleted */

/* Returns NULL if not found */
MsgIdNode *hashtree_lookup(HashTree *, const char *msgid);

/* Adds a virginal (subject to not already being added) message */
MsgIdNode *hashtree_add(HashTree *, const char *msgid);

void hashtree_change_status(MsgIdNode *, msgid_Status);

/* In practice we only use one HashTree */
extern HashTree *the_hashtree;

#endif /* HASHTREE_H */
