#ifndef HISTORY_H 
#define HISTORY_H 

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Abstraction for checking whether Message-IDs are already present on local
 * server */


#ifndef DEFNS_H
#include "defns.h"
#endif

/* Returns TRUE if message exists. Actually forwards to a function provided by
 * one of a number of implementations */
BOOL history_check(const char *msgid);

/* Adds a msgid to history (if implementation supports it) when a message is
 * downloaded */
void history_add(const char *msgid);

/* For implementations to register their services. Each implementation should
 * register any options they need in main.cf first, then whichever is in use
 * should be called to initialise itself, set any exit handler it needs, and
 * call history_register_implementation */

/* An implementation of history_check */
typedef BOOL (*history_check_hook)(const char *msgid);

/* An implementation of history_add */
typedef void (*history_add_hook)(const char *msgid);

/* Call to register above; history_add_hook may be NULL if not supported */
void history_register_implementation(history_check_hook, history_add_hook);

#endif /* HISTORY_H */
