/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"

#ifdef HAVE_GDBM_H

#include <gdbm.h>

#include "histsnews.h"
#include "history.h"
#include "maincf.h"

static char *histsnews_filename = NULL;

static GDBM_FILE histsnews_open(char *filename)
{
    GDBM_FILE dbf = gdbm_open(filename, 1024, GDBM_READER, 0666, NULL);

    if (!dbf)
    {
	deblog_error(_("Unable to open history database: %s\n"),
		gdbm_strerror(gdbm_errno));
    }
    return dbf;
}

static BOOL histsnews_check(const char *msgid)
{
    datum key;
    BOOL result;
    GDBM_FILE dbf = histsnews_open(histsnews_filename);
    
    key.dptr = XSTRDUP(msgid);
    key.dsize = strlen(key.dptr) + 1;
    result = gdbm_exists(dbf, key);
    free(key.dptr);
    gdbm_close(dbf);
    return result;
}

void histsnews_init(void)
{
    /* gdbm_open lacks const for filename, so use copy to avoid warning */
    histsnews_filename = XSTRDUP(maincf_get_snews_history());
    history_register_implementation(histsnews_check, NULL);
    /* Do a test open to make sure it works */
    gdbm_close(histsnews_open(histsnews_filename));
}

#endif /* HAVE_GDBM_H */
