#ifndef KIDDY_H
#define KIDDY_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Child processes as seen by the parent */


#ifndef COMMON_H
#include "common.h"
#endif

#include "intercom.h"

#if USE_PTHREADS
#include <pthread.h>
#include "main.h"
typedef pthread_t kiddy_thread_t;
#define MAIN_PID main_thread
#else
typedef pid_t kiddy_thread_t;
#define MAIN_PID -1
#endif

struct KiddyData {
    NSThread *thread;		/* Thread curently assigned to it */
    IntercomQ *queue;		/* For sending messages to child */
    kiddy_thread_t pid;
    int thread_idx;
};

/* Find a process which is available (or return NULL) */
KiddyData *kiddy_get_available(void);

/* Spawn all child processes at start */
void kiddy_spawn_all(void);

/* Get next command from queue sent by children */
const intercom_data *kiddy_get_command(void);

void kiddy_detach_thread(KiddyData *);

/* How many threads are active */
extern int kiddy_nthreads;

/* Iterates through threads; start with NULL to get first thread,
 * returns NULL after last thread */
NSThread *kiddy_get_next_thread(const NSThread *);

#endif /* kiddy_H */
