#ifndef NSCURSES_H 
#define NSCURSES_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Interface for outputting via curses instead of stdout/stderr */


#ifndef COMMON_H
#include <common.h>
#endif

#ifdef HAVE_CURSES_H

/* Whether we're using curses interface */
BOOL nscurses_active(void);

/* Start using curses, set up windows etc; needs to know how many threads are
 * in use to divide up screen */
void nscurses_start(int nthreads);

/* Stop using curses and clear screen etc */
void nscurses_stop(void);

/* As above, but a bit more abrupt */
void nscurses_emergency_stop(void);
    
/* Output a message for deblog (thread_idx == -1 for parent) */
void nscurses_deblog(int thread_idx, deblog_level_t level, const char *message);

/* Output stats (rates are xntokilomeg strings) */
void nscurses_stats(long int downloaded, long int total_downloads,
	long int total_seen,
	const char *download_rate,
	long int uploaded, long int total_uploads, const char *upload_rate);

/* Indicate which server a thread is connected to */
void nscurses_server(int thread_idx, const char *name);

/* Show miscellaneous status message for a thread */
void nscurses_show_status(int thread_idx, const char *message);

#else /* ! HAVE_CURSES */

#define nscurses_active() FALSE
#define nscurses_start(n)
#define nscurses_stop()
#define nscurses_emergency_stop()
#define nscurses_deblog(t, l, m)
#define nscurses_stats(d, td, ts, dr, u, tu, ur)
#define nscurses_server(t, n)
#define nscurses_show_status(t, m)

#endif /* HAVE_CURSES_H */

#endif /* NSCURSES_H */
