#ifndef NSTHREAD_H
#define NSTHREAD_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* A logical thread as seen by the parent process */


#ifndef DEFNS_H
#include "defns.h"
#endif
#ifndef INTERCOM_H
#include "intercom.h"
#endif

/* Status wrt waiting for a group's stats to become available */
typedef enum {
    nsthread_NotWaiting,	/* All groups had stats, no waiting at all */
    nsthread_WillWait,		/* Currently flushing pipeline, will enter
				   _Waiting state when flushed */
    nsthread_Waiting,		/* Dormant until another thread wakes it with
				   stats */
    nsthread_WakeUp		/* Another thread got stats while this one was
				   in _WillWait */
} nsthread_WaitState;

struct NSThread {
    KiddyData *kiddy;
    ServerData *serv;
    int thread_idx;
    long int group_ix;	/* Which group we last entered */
    BOOL upload_first;	/* Whether outgoing articles should be uploaded before
			   downloading incoming ones */
    const char *
    all_downloaded_msg;	/* Message to display on receipt of
			   command_AllDownloaded */
    nsthread_WaitState wait_state;
    char *command;	/* Last received command; may be split by
			   command_SplitCommand */
};

/* Creates a new thread, finds a kiddy to run it on, connects and logs in etc,
 * returns NULL if all available threads are in use. */
NSThread *nsthread_new(ServerData *serv, BOOL upload_first);

void nsthread_delete(NSThread *);

/* Returns struct ptr associated with an index */
NSThread *nsthread_lookup(int thread_idx);

void nsthread_send_command(NSThread *thread, intercom_Command code, const char
	*data, ...);

#endif /* NSTHREAD_H */
