#ifndef PARSERC_H
#define PARSERC_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Parses the config file */


#ifndef DEBLOG_H
#include "deblog.h"
#endif
#ifndef DEFNS_H
#include "defns.h"
#endif

/* When the parser encounters a line beginning with a keyword it calls the
 * handler registered for that keyword with the whole line minus leading
 * whitespace and the data handle associated with that keyword. A handler
 * should return NULL if it reads the line OK, or an error message otherwise.
 * When reported, the error message will have " in line XX: `THELINE'\n"
 * appended
 */
typedef const char *(*parserc_handler)(const char *keyword, const char *value,
	void *data_handle);

void parserc_register_handler(const char *keyword, parserc_handler, void
	*data_handle);

/* Register internal handlers for the various types of line in a newsqrc file
 */

void parserc_register_int(const char *keyword, long int *value);

void parserc_register_bool(const char *keyword, BOOL *value);

/* *value is freeable */
void parserc_register_string(const char *keyword, char **value);

/* Value is ignored */
void parserc_register_ignored(const char *keyword);

/* This can be used instead of above handlers, if you want to look at every
 * processed line without knowing keywords in advance */
void parserc_register_master_handler(parserc_handler, void *data_handle);

/* Parse the file then deregister all the above handlers, and close file */
void parserc_read(int filedes);

/* As above but opens and closes the file; deblog level is for message if file
 * isn't present */
void parserc_read_named(const char *filename, deblog_level_t);

#endif /* PARSERC_H */

