/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#include "common.h"
#include "snstore.h"

rw_buf *snstore_init(const char *command)
{
    int snstr_pipe[2];
    rw_buf *snstr_buf;

    XPIPE(snstr_pipe);
    switch (fork())
    {
	case -1:
	    deblog_error(_("Unable to fork: %s\n"), strerror(errno));
	    return NULL;
	case 0:
	    /* Child, convert stdin to read from pipe and run snstore */
	    close(0);
	    XDUP(snstr_pipe[0]);
	    close(snstr_pipe[0]);
	    close(snstr_pipe[1]);
	    execlp(command, command, "-c", NULL);
	    deblog_error(_("Unable to exec snstore: %s\n"), strerror(errno));
	    return NULL;
	default:
	    /* Parent, create buffer for pipe */
	    close(snstr_pipe[0]);	/* Don't need to read at this end */
	    snstr_buf = rw_create_buf(snstr_pipe[1], TRUE, FALSE, -1);
	    return snstr_buf;
    }
    return NULL;
}

