#ifndef STATS_H 
#define STATS_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Prints info about how many articles have been downloaded etc */


#ifndef COMMON_H
#include "common.h"
#endif

/* Reads time at start for summary calculation */
void stats_start(void);

/* Increment record of how many articles are to be downloaded (starts at 0) */
void stats_inc_total_to_fetch(void);

/* How many articles have been seen ("by" is how many articles to add) */
void stats_inc_total_seen(long int by);

/* Decrement number to be downloaded (when we find a x-post or duplicate) */
void stats_dec_total_to_fetch(void);

/* Increment record of how many articles have been downloaded (starts at 0) */
void stats_inc_fetched(void);

/* Increment record of how many out of order/backfilled articles have been
 * downloaded (starts at 0) */
void stats_inc_backfilled(void);

/* How many have been killed by score */
void stats_inc_killed(void);

/* Update stats display without changing any values */
void stats_update(BOOL force);

/* Display summary of all stats at end */
void stats_summary(void);

/* Keep stats (display) updated with how many bytes have been received or sent
 */
void stats_update_bytes_rcvd(long int bytes, const struct timeval *tv);
void stats_update_bytes_sent(long int bytes, const struct timeval *tv);

/* Update counts of articles skipped because they've already been downloaded by
 * this session or are already present on server respectively */
void stats_inc_current_dups(void);
void stats_inc_history_dups(void);

/* Upload stats */
void stats_inc_total_to_upload(void);
void stats_dec_total_to_upload(void);
void stats_inc_uploaded(void);
void stats_inc_duplicates(void);
void stats_inc_bad_uploads(void);

/* Call to disable running stats display when not in curses mode */
void stats_quiet(void);

/* Clears current line of running stats */
void stats_clear_line(void);

/* How often stats are updated */
extern struct timeval stats_interval;

#endif /* STATS_H */
