#ifndef STDX_H
#define STDX_H

/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Enhancements and extensions to std C library */


#ifndef COMMON_H
#include "common.h"
#endif

/* These log error message and exit if fail. */
void *xmalloc(size_t, const char *msg, ...);
void *xrealloc(void *, size_t, const char *msg, ...);
void *xcalloc(size_t, size_t, const char *msg, ...);
#define XMALLOC(s) xmalloc((s), _("Out of memory\n"))
#define XREALLOC(b, s) xrealloc((b), (s), _("Out of memory\n"))
#define XCALLOC(n, s) xcalloc((n), (s), _("Out of memory\n"))

char *xstrdup(const char *s, const char *msg, ...);
#define XSTRDUP(s) xstrdup((s), _("Out of memory\n"))

char *xstrdupcat(const char *s1, const char *s2, const char *msg, ...);
#define XSTRDUPCAT(s1, s2) xstrdupcat((s1), (s2), _("Out of memory\n"))

int xpipe(int fd[2], const char *msg, ...);
#define XPIPE(fd2) xpipe((fd2), _("Unable to open pipes"));

/* Finds the difference between 2 times */
void xtimeval_subtract(struct timeval *higher, struct timeval *lower, struct
	timeval *result); 
/* Converts a timeval to floating point, ignoring anything over an hour */
#define FLOAT_TV(ftv) \
    ((double) ((ftv)->tv_sec % 3600) + (double) (ftv)->tv_usec / 1E6)

/* Converts a number into K/M etc notation if it's big; result is overwritten
 * by susequent calls; recursive, suffix must be 0 on entry */
const char *xntokilomeg(long int n, char suffix);
#define XNTOKILOMEG(n) xntokilomeg((n), 0)

/* If fatal, error is logged with deblog_error, otherwise deblog_critical */
int xmkstemp(char *name, BOOL fatal, const char *msg, ...);
int xvmkstemp(char *name, BOOL fatal, const char *msg, va_list ap);
/* *filename is created with malloc (including if there's an error) and should
 * be freed when finished with */
int xmktmpindir(const char *dir, const char *template, char **filename, BOOL
	fatal, const char *msg, ...);
#define XMKTMPINDIR(d, t, f) xmktmpindir((d), (t), (f), TRUE, \
	_("Can't create temporary"))

#define XMAX(a, b) ((a) >= (b) ? (a) : (b))
#define XMIN(a, b) ((a) <= (b) ? (a) : (b))

int xremove(const char *filename, const char *msg, ...);
#define XREMOVE(f) xremove((f), _("Can't delete %s\n"), (f))

int xdup(int oldfd, const char *msg, ...);
#define XDUP(f) xdup((f), _("Can't duplicate file descriptor\n"))

#endif /* STDX_H */
